get_laces_row

Function get_laces_row 

pub fn get_laces_row(
    reply: MeasurementReply,
    rx_worker_id: &u32,
    worker_map: &BiHashMap<u32, String>,
    origin_id: u32,
) -> Vec<String>
Get the result (csv row) from a Reply message

Arguments

  • reply - The Reply that is being written to this row
  • rx_worker_id - The worker ID of the receiver
  • worker_map - A map of worker IDs to hostnames, used to convert worker IDs to hostnames in the results
  • origin_id - Associated origin ID of the reply

Returns

A vector of strings representing the row in the CSV file

Note

The rtt column carries the signed offset rx_time - tx_time (milliseconds), computed on the worker. Under anycast the sender (tx) and receiver (rx) may be different PoPs, so it may be negative.